"""
File:  advanced_die.py
Description: Provides a AdvancedDie class that allows for any number of sides
Inherits from the parent class Die in module die_simple
"""
from die_simple import Die
from random import randint

class AdvancedDie(Die):
    """Advanced die class that allows for any number of sides"""

    def __init__(self, *args):
        """Constructor for any sided Die that takes an the number of sides 
        as a parameter; if no parameter given then default is 6-sided."""
        # call Die parent class constructor 
        Die.__init__(self)
        if len(args) == 0:
            self._numSides = 6
        elif len(args) == 1 and isinstance(args[0], int):
            self._numSides = args[0]
        else:
            print "Usage:  Die() or Die(numberOfSides)"
            return None
        
        self._currentRoll = randint(1, self._numSides)

    def roll(self):
        """Causes a die to roll itself -- overrides Die class roll"""
        self._currentRoll = randint(1, self._numSides)
        return self._currentRoll
    
    def show(self):
        """Displays a Die by printing it"""
        print self._currentRoll

    def __cmp__(self, rhs_Die):
        """Overrides the '__cmp__' operator for Dies, to allow for
        to allow for a deep comparison of two Dice"""
        
        if self._currentRoll < rhs_Die._currentRoll:
            return -1
        elif self._currentRoll == rhs_Die._currentRoll:
            return 0
        else:
            return 1

